==> zio-aws-cognitoidentityprovider_2.12-5.17.295.17-sources.jar: zio/aws/cognitoidentityprovider/model/ConfirmSignUpRequest.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.cognitoidentityprovider.model.primitives.{
  ConfirmationCodeType,
  SecretHashType,
  ForceAliasCreation,
  UsernameType,
  ClientIdType,
  StringType
}
import scala.jdk.CollectionConverters._
final case class ConfirmSignUpRequest(
    clientId: ClientIdType,
    secretHash: Optional[SecretHashType] = Optional.Absent,
    username: UsernameType,
    confirmationCode: ConfirmationCodeType,
    forceAliasCreation: Optional[ForceAliasCreation] = Optional.Absent,
    analyticsMetadata: Optional[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType
    ] = Optional.Absent,
    userContextData: Optional[
      zio.aws.cognitoidentityprovider.model.UserContextDataType
    ] = Optional.Absent,
    clientMetadata: Optional[Map[StringType, StringType]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest = {
    import ConfirmSignUpRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
      .builder()
      .clientId(ClientIdType.unwrap(clientId): java.lang.String)
      .optionallyWith(
        secretHash.map(value => SecretHashType.unwrap(value): java.lang.String)
      )(_.secretHash)
      .username(UsernameType.unwrap(username): java.lang.String)
      .confirmationCode(
        ConfirmationCodeType.unwrap(confirmationCode): java.lang.String
      )
      .optionallyWith(
        forceAliasCreation.map(value =>
          ForceAliasCreation.unwrap(value): java.lang.Boolean
        )
      )(_.forceAliasCreation)
      .optionallyWith(analyticsMetadata.map(value => value.buildAwsValue()))(
        _.analyticsMetadata
      )
      .optionallyWith(userContextData.map(value => value.buildAwsValue()))(
        _.userContextData
      )
      .optionallyWith(
        clientMetadata.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.clientMetadata)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly =
    zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest
      .wrap(buildAwsValue())
}
object ConfirmSignUpRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest =
      zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest(
        clientId,
        secretHash.map(value => value),
        username,
        confirmationCode,
        forceAliasCreation.map(value => value),
        analyticsMetadata.map(value => value.asEditable),
        userContextData.map(value => value.asEditable),
        clientMetadata.map(value => value)
      )
    def clientId: ClientIdType
    def secretHash: Optional[SecretHashType]
    def username: UsernameType
    def confirmationCode: ConfirmationCodeType
    def forceAliasCreation: Optional[ForceAliasCreation]
    def analyticsMetadata: Optional[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ]
    def userContextData: Optional[
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ]
    def clientMetadata: Optional[Map[StringType, StringType]]
    def getClientId: ZIO[Any, Nothing, ClientIdType] = ZIO.succeed(clientId)
    def getSecretHash: ZIO[Any, AwsError, SecretHashType] =
      AwsError.unwrapOptionField("secretHash", secretHash)
    def getUsername: ZIO[Any, Nothing, UsernameType] = ZIO.succeed(username)
    def getConfirmationCode: ZIO[Any, Nothing, ConfirmationCodeType] =
      ZIO.succeed(confirmationCode)
    def getForceAliasCreation: ZIO[Any, AwsError, ForceAliasCreation] =
      AwsError.unwrapOptionField("forceAliasCreation", forceAliasCreation)
    def getAnalyticsMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ] = AwsError.unwrapOptionField("analyticsMetadata", analyticsMetadata)
    def getUserContextData: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ] = AwsError.unwrapOptionField("userContextData", userContextData)
    def getClientMetadata: ZIO[Any, AwsError, Map[StringType, StringType]] =
      AwsError.unwrapOptionField("clientMetadata", clientMetadata)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ) extends zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly {
    override val clientId: ClientIdType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ClientIdType(impl.clientId())
    override val secretHash: Optional[SecretHashType] = zio.aws.core.internal
      .optionalFromNullable(impl.secretHash())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives.SecretHashType(value)
      )
    override val username: UsernameType =
      zio.aws.cognitoidentityprovider.model.primitives
        .UsernameType(impl.username())
    override val confirmationCode: ConfirmationCodeType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ConfirmationCodeType(impl.confirmationCode())
    override val forceAliasCreation: Optional[ForceAliasCreation] =
      zio.aws.core.internal
        .optionalFromNullable(impl.forceAliasCreation())
        .map(value =>
          zio.aws.cognitoidentityprovider.model.primitives
            .ForceAliasCreation(value)
        )
    override val analyticsMetadata: Optional[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.analyticsMetadata())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.wrap(value)
      )
    override val userContextData: Optional[
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.userContextData())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.UserContextDataType.wrap(value)
      )
    override val clientMetadata: Optional[Map[StringType, StringType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.clientMetadata())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: StringType) -> (value: StringType)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ): zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.123.1-sources.jar: zio/aws/cognitoidentityprovider/model/ConfirmSignUpRequest.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.{
  ConfirmationCodeType,
  SecretHashType,
  ForceAliasCreation,
  UsernameType,
  ClientIdType,
  StringType
}
import scala.jdk.CollectionConverters._
final case class ConfirmSignUpRequest(
    clientId: ClientIdType,
    secretHash: Option[SecretHashType] = None,
    username: UsernameType,
    confirmationCode: ConfirmationCodeType,
    forceAliasCreation: Option[ForceAliasCreation] = None,
    analyticsMetadata: Option[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType
    ] = None,
    userContextData: Option[
      zio.aws.cognitoidentityprovider.model.UserContextDataType
    ] = None,
    clientMetadata: Option[Map[StringType, StringType]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest = {
    import ConfirmSignUpRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
      .builder()
      .clientId(ClientIdType.unwrap(clientId): java.lang.String)
      .optionallyWith(
        secretHash.map(value => SecretHashType.unwrap(value): java.lang.String)
      )(_.secretHash)
      .username(UsernameType.unwrap(username): java.lang.String)
      .confirmationCode(
        ConfirmationCodeType.unwrap(confirmationCode): java.lang.String
      )
      .optionallyWith(
        forceAliasCreation.map(value =>
          ForceAliasCreation.unwrap(value): java.lang.Boolean
        )
      )(_.forceAliasCreation)
      .optionallyWith(analyticsMetadata.map(value => value.buildAwsValue()))(
        _.analyticsMetadata
      )
      .optionallyWith(userContextData.map(value => value.buildAwsValue()))(
        _.userContextData
      )
      .optionallyWith(
        clientMetadata.map(value =>
          value
            .map({ case (key, value) =>
              (StringType.unwrap(key): java.lang.String) -> (StringType
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.clientMetadata)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly =
    zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest
      .wrap(buildAwsValue())
}
object ConfirmSignUpRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest =
      zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest(
        clientId,
        secretHash.map(value => value),
        username,
        confirmationCode,
        forceAliasCreation.map(value => value),
        analyticsMetadata.map(value => value.asEditable),
        userContextData.map(value => value.asEditable),
        clientMetadata.map(value => value)
      )
    def clientId: ClientIdType
    def secretHash: Option[SecretHashType]
    def username: UsernameType
    def confirmationCode: ConfirmationCodeType
    def forceAliasCreation: Option[ForceAliasCreation]
    def analyticsMetadata: Option[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ]
    def userContextData: Option[
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ]
    def clientMetadata: Option[Map[StringType, StringType]]
    def getClientId: ZIO[Any, Nothing, ClientIdType] = ZIO.succeed(clientId)
    def getSecretHash: ZIO[Any, AwsError, SecretHashType] =
      AwsError.unwrapOptionField("secretHash", secretHash)
    def getUsername: ZIO[Any, Nothing, UsernameType] = ZIO.succeed(username)
    def getConfirmationCode: ZIO[Any, Nothing, ConfirmationCodeType] =
      ZIO.succeed(confirmationCode)
    def getForceAliasCreation: ZIO[Any, AwsError, ForceAliasCreation] =
      AwsError.unwrapOptionField("forceAliasCreation", forceAliasCreation)
    def getAnalyticsMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ] = AwsError.unwrapOptionField("analyticsMetadata", analyticsMetadata)
    def getUserContextData: ZIO[
      Any,
      AwsError,
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ] = AwsError.unwrapOptionField("userContextData", userContextData)
    def getClientMetadata: ZIO[Any, AwsError, Map[StringType, StringType]] =
      AwsError.unwrapOptionField("clientMetadata", clientMetadata)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ) extends zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly {
    override val clientId: ClientIdType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ClientIdType(impl.clientId())
    override val secretHash: Option[SecretHashType] = scala
      .Option(impl.secretHash())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives.SecretHashType(value)
      )
    override val username: UsernameType =
      zio.aws.cognitoidentityprovider.model.primitives
        .UsernameType(impl.username())
    override val confirmationCode: ConfirmationCodeType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ConfirmationCodeType(impl.confirmationCode())
    override val forceAliasCreation: Option[ForceAliasCreation] = scala
      .Option(impl.forceAliasCreation())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives
          .ForceAliasCreation(value)
      )
    override val analyticsMetadata: Option[
      zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly
    ] = scala
      .Option(impl.analyticsMetadata())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.wrap(value)
      )
    override val userContextData: Option[
      zio.aws.cognitoidentityprovider.model.UserContextDataType.ReadOnly
    ] = scala
      .Option(impl.userContextData())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.UserContextDataType.wrap(value)
      )
    override val clientMetadata: Option[Map[StringType, StringType]] = scala
      .Option(impl.clientMetadata())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.cognitoidentityprovider.model.primitives.StringType(
              key
            ) -> zio.aws.cognitoidentityprovider.model.primitives
              .StringType(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.ConfirmSignUpRequest
  ): zio.aws.cognitoidentityprovider.model.ConfirmSignUpRequest.ReadOnly =
    new Wrapper(impl)
}
